<?php
/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

// FILE NAME:       index.php
// AUTHOR:          Marcos Martinez Jimenez

if (isset($_POST['nick'])) {$login=$_POST['nick'];} else {$login="";}
if (isset($_POST['password'])){$password=crypt($_POST['password'],'zzxzv');} else {$password="";}
if (isset($_GET['num'])) {$numero=$_GET['num'];}
if (isset($_GET['logout'])) {$logout=$_GET['logout'];} else {$logout="no";}

include ("includes/config_site.php");

// If someone is trying to login with a nick and password,
// then the received data is checked to know if it's correct
if (!empty($login) && !empty($password))
   {
   include ("includes/db_connect.php");
   $consulta=mysql_query("SELECT nick, password, id_user FROM users WHERE nick='$login'",$db);
   $datos_form=mysql_fetch_array($consulta);
   } else {$datos_form = array ("nick"  => "", "password" => "");} // to prevent error messages,
                                                                   // if the user didn't provide
                                                                   // a nickname and password,
                                                                   // then, a default one is defined


// When one user choose the logout option, then his cookie should to be expired.
if ( $logout == "yes" )
   {
   setcookie("id_session[id_user]",0,0,"","",0);
   }

if($login==$datos_form["nick"] && $password==$datos_form["password"] && !empty($login) && !empty($password))
  {
  // The initial seed of the random number generator is created using the number
  // of microseconds since the last integer (in seconds).
  srand((double)microtime()*1000000);
  $num = rand(); // This value will be used to authenticate the user sessions
  setcookie("id_session[num]",$num,0,"","",0);
  setcookie("id_session[user]",$login,0,"","",0);
  setcookie("id_session[id_user]",$datos_form["id_user"],0,"","",0);
  } else $num=$numero; // If the user still logged, then the $num value don't change


if($login!=$datos_form["nick"] ) $AUTH_LOGIN="no";
if ($password!=$datos_form["password"]) $AUTH_PASSWD="no";

include ("includes/draw_main_table.php");
include ("includes/draw_functions.php");
?>

<html>
<head>
<link rel="shortcut icon" href="/www/homesite/favicon.ico" type="image/x-icon" />
<link rel="icon" href="/www/homesite/favicon.ico" type="image/x-icon" />
<link rel="stylesheet" href="images/skins/<? echo "$SKIN"?>/style.css" type="text/css">
<title><? echo "$TITLE" ?></title>

</head>

<body bgcolor=<? echo "$BGCOLOR"?>>


<table border="0" width=<? echo $HEADER_WIDTH?> align="center" bgcolor=<? echo $BGCOLOR?>>
<tr>

<?php
if ($SIZE_BOX1>0)
   {
   echo "<td width=$WIDTH_BOX1>";
   draw_table ($COLOR_BOX1,$SIZE_BOX1,"".$LOGO_BOX1."","",$SKIN_BOX1,"","","","");
   echo "</td>";
   }

if ($SIZE_BOX2>0)
   {
   echo "<td width=$WIDTH_BOX2>";
   draw_table ($COLOR_BOX2,$SIZE_BOX2,"".$LOGO_BOX2."","",$SKIN_BOX2,"","","","");
   echo "</td>";
   }

if ($SIZE_BOX3>0)
   {
   echo "<td width=$WIDTH_BOX3>";
   draw_table ($COLOR_BOX3,$SIZE_BOX3,"".$LOGO_BOX3."","",$SKIN_BOX3,"","","","");
   echo "</td>";
   }

if ($SIZE_BOX4>0)
   {
   echo "<td width=$WIDTH_BOX4>";
   draw_table ($COLOR_BOX4,$SIZE_BOX4,"".$LOGO_BOX4."","",$SKIN_BOX4,"","","","");
   echo "</td>";
   }
?>

</tr>
</table>

<table border="0" width=<? echo $BODY_WIDTH ?> align="center" bgcolor=<? echo $BGCOLOR?>>

<tr><td width="15%"></td><td width="15%"></td><td width="55%"></td><td width="15%"></td></tr>

<tr>
<!-- LEFT BOX -->
<td valign="top"><? draw_table ($COLOR_LEFT_BOX,$SIZE_LEFT_BOX,"EXTERNO","includes/left_table.php",$SKIN_LEFT_BOX,$num,"","","") ?></td>

<td colspan="2" valign="top">

<!-- STARTING MAIN TABLE (with tabs) -->

  <table border="0" cellspacing="0" cellpadding="0" width="100%">

  <tr> <!-- STARTING FIRST ROW (A) -->
  <td rowspan="2" width="21"><img src="images/skins/<? echo "$SKIN"?>/tags/B_1TL.png" border="0"></td>
  <td height="8" width="25%"><a href="index.php?top_tab=1"><img src="images/skins/<? echo "$SKIN"?>/tags/B_0TM.png" height="8"  width="100%" border="0"></a></td>
  <td rowspan=2" width="27"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$A3" ?>.png" border="0"></td>
  <td height="8" width="25%"><a href="index.php?top_tab=2"><img src="images/skins/<? echo "$SKIN"?>/tags/Y_0TM.png" height="8" width="100%" border="0"></a></td>
  <td rowspan=2" width="27"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$A5" ?>.png" border="0"></td>
  <td height="8" width="25%"><a href="index.php?top_tab=3"><img src="images/skins/<? echo "$SKIN"?>/tags/M_0TM.png" height="8" width="100%" border="0"></a></td>
  <td rowspan=2" width="27"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$A7" ?>.png" border="0"></td>
  <td height="8" width="25%"><a href="index.php?top_tab=4"><img src="images/skins/<? echo "$SKIN"?>/tags/G_0TM.png" height="8" width="100%" border="0"></a></td>
  <td rowspan=2" width="26"><img src="images/skins/<? echo "$SKIN"?>/tags/G_1TR.png" border="0"></td>
  </tr> <!-- ENDING FIRST ROW (A) -->

  <tr> <!-- STARTING ROW (A') -->

  <?php // If the control panel has been called, then it's showed in the fisrt tab
  if (!isset($_GET['top_tab'])) { $requested_tab=$DEFAULT_TAB; } else $requested_tab=$_GET['top_tab'];
  if ($requested_tab==5)
     {
     echo "<td align=\"center\" height=\"23\" width=\"25%\" bgcolor=\"$COLOR1\">".
          "<a class=\"link3\" href=\"index.php?top_tab=1&num=$num\">$TAB_5</a></td>";
     } else {
            echo "<td align=\"center\" height=\"23\" width=\"25%\" bgcolor=\"$COLOR1\">".
                 "<a class=\"link3\" href=\"index.php?top_tab=1&num=$num\">$TAB_1</a></td>";
            }
  ?>

  <td align="center" height="23" width="25%" bgcolor="<? echo "$COLOR2"?>">
  <a class="link3" href="index.php?top_tab=2&<? echo "num=$num"?>"><? echo "$TAB_2" ?></a>
  </td>

  <td align="center" height="23" width="25%" bgcolor="<? echo "$COLOR3"?>">
  <a class="link3" href="index.php?top_tab=3&<? echo "num=$num"?>"><? echo "$TAB_3" ?></a>
  </td>

  <td align="center" height="23" width="25%" bgcolor="<? echo "$COLOR4"?>">
  <a class="link3" href="index.php?top_tab=4&<? echo "num=$num"?>"><? echo "$TAB_4" ?></a>
  </td>

  </tr> <!-- ENDING ROW (A') -->

  <tr> <!-- STARTING ROW (B) -->
  <td width="21"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B1" ?>.png" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B2" ?>.png" height="12" width="100%" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B3" ?>.png" height="12" width="100%" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B4" ?>.png" height="12" width="100%" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B5" ?>.png" height="12" width="100%" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B6" ?>.png" height="12" width="100%" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B7" ?>.png" height="12" width="100%" border="0"></td>
  <td height="12"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B8" ?>.png" height="12" width="100%" border="0"></td>
  <td width="26"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$B9" ?>.png" border="0"></td>
  </tr><!-- ENDING ROW (B) -->

  <tr><!-- STARTING ROW (C) -->
  <td height="100%" width="21" valign="top">
  <img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$C1" ?>.png" height="100%" width="21" border="0">
  </td>
  <td colspan="7" bgcolor="<? echo "$C2" ?>" valign="top">

  <?php 
  echo "<table border=\"0\" width=\"100%\" valign=\"top\" cellpadding=\"0\" cellspacing=\"0\">";

  // Getting the section names values from the config.php file

  $section_1="TAB_".$requested_tab."1";
  $section_2="TAB_".$requested_tab."2";
  $section_3="TAB_".$requested_tab."3";
  $section_4="TAB_".$requested_tab."4";

  if (!isset($_GET['section_type'])) { $requested_section=$DEFAULT_SECTION; } else $requested_section=$_GET['section_type'];

  // Getting the section types values from the config.php file

  $type_section="SECTION_TYPE_".$requested_tab."".$requested_section."";
  $name_section="TAB_".$requested_tab."".$requested_section."";
  $name_tab="TAB_".$requested_tab."";

  echo "<tr valign=\"top\">\n".
       "<td class=\"link1-blue\" align=\"right\">\n";
  if ($$section_1!="NO") echo "<a href=\"index.php?top_tab=".$requested_tab."&section_type=1&num=$num\" >".$$section_1."</a>&nbsp;\n";
  if ($$section_2!="NO") echo "|&nbsp;<a href=\"index.php?top_tab=".$requested_tab."&section_type=2&num=$num\" >".$$section_2."</a>&nbsp;\n";
  if ($$section_3!="NO") echo "|&nbsp;<a href=\"index.php?top_tab=".$requested_tab."&section_type=3&num=$num\" >".$$section_3."</a>&nbsp;\n";
  if ($$section_4!="NO") echo "|&nbsp;<a href=\"index.php?top_tab=".$requested_tab."&section_type=4&num=$num\" >".$$section_4."</a>\n";
  echo "</td></tr>\n";
  echo "<tr><td>\n";

  include ("includes/dbwa.php");      // Includes the DataBase Write Agent (DBWA)
  include ("".$$type_section.".php"); // Includes the proper section file

  echo "</td></tr>\n";
  echo "</table>\n";

  ?>
  </td>
  <td height="100%" width="26" valign="top">
  <img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$C3" ?>.png" height="100%" width="26" border="0">
  </td>
  </tr><!-- ENDING ROW (C) -->

  <tr valign="top"><!-- STARTING ROW (D) -->
  <td width="21" height="100%"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$D1" ?>.png" border="0" height="12"></td>
  <td height="100%" colspan=7><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$D2" ?>.png" height="12" width="100%" border="0" align="top">
  </td>
  <td width="26" height="100%"><img src="images/skins/<? echo "$SKIN"?>/tags/<? echo "$D9" ?>.png" border="0" height="12"></td>
  </tr><!-- ENDING ROW (D) -->
  </table>

</td>

<!-- ENDING MAIN TABLE (with tabs) -->

<td valign="top">
<!-- RIGHT BOX -->
<? draw_table ($COLOR_BOX5,$SIZE_BOX5,"".$LOGO_BOX5."","",$SKIN_BOX5,"","","","") ?><br>

<!-- LOGIN BOX -->
<? draw_table ($COLOR_LOGIN_BOX,$SIZE_LOGIN_BOX,"EXTERNO","includes/login.php",$SKIN_LOGIN_BOX,$num,$id_session,$AUTH_LOGIN,$AUTH_PASSWD) ?> 

</td></tr>

<tr> <!-- FOOTER BOX -->
<td colspan=4>
<? draw_table ($COLOR_FOOTER_BOX,$SIZE_FOOTER_BOX,"<div class=\"text1\" align=\"center\">".$LOGO_FOOTER_BOX."</div>","","$SKIN_FOOTER_BOX","","","","") ?></td>
</tr>

</table>
</body>
</html>

